==> libreoffice-4.0.3.3.tar.xz: libreoffice-4.0.3.3/forms/source/component/findpos.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include "sal/config.h"

#include "findpos.hxx"

#include "com/sun/star/uno/Sequence.hxx"
#include "comphelper/types.hxx"
#include "rtl/ustring.hxx"
#include "sal/types.h"

#include <algorithm>

namespace detail {

sal_Int32 findPos(
    const ::rtl::OUString& aStr,
    const ::com::sun::star::uno::Sequence< ::rtl::OUString >& rList)
{
    const ::rtl::OUString* pStrList = rList.getConstArray();
    const ::rtl::OUString* pResult = ::std::lower_bound(
        pStrList, pStrList + rList.getLength(), aStr );
    if ( ( pResult != pStrList + rList.getLength() ) && ( *pResult == aStr ) )
        return ( pResult - pStrList );

    return -1;
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_5.1.2.orig.tar.xz: libreoffice-5.1.2/forms/source/component/findpos.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include "sal/config.h"

#include "findpos.hxx"

#include "com/sun/star/uno/Sequence.hxx"
#include "comphelper/types.hxx"
#include "rtl/ustring.hxx"
#include "sal/types.h"

#include <algorithm>

namespace detail {

sal_Int32 findPos(
    const OUString& aStr,
    const css::uno::Sequence< OUString >& rList)
{
    const OUString* pStrList = rList.getConstArray();
    const OUString* pResult = ::std::lower_bound(
        pStrList, pStrList + rList.getLength(), aStr );
    if ( ( pResult != pStrList + rList.getLength() ) && ( *pResult == aStr ) )
        return ( pResult - pStrList );

    return -1;
}

}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
